@@ -7,6 +7,7 @@
 #' @param inputId The \code{input} slot that will be used to access the value.
 #' @param icon An icon to appear on the button.
 #' @param status Color of the button.
+#' @param size Size of the button : default, lg, sm, xs.
 #' @param ... Named attributes to be applied to the button.
 #'
 #'
@@ -16,14 +17,12 @@
 #' @export
 
 
-circleButton <- function (inputId, icon = NULL, status = "default", ...)
+circleButton <- function (inputId, icon = NULL, status = "default", size = "default", ...)
 {
-  htmltools::tagList(
-    htmltools::singleton(
-      tags$head(tags$link(rel='stylesheet', type='text/css',
-                          href='shinyWidgets/circleButton/circle-button.css'))
-    ),
-    tags$button(id = inputId, type = "button",
-      class = paste0("btn btn-", status, " btn-circle action-button"), icon, ...)
+  attachShinyWidgetsDep(
+    tags$button(
+      id = inputId, type = "button", style = "outline: none;",
+      class = paste0("btn btn-", status, " action-button ", ifelse(size == "default", "btn-circle", paste0("btn-circle-", size))), icon, ...
+    )
   )
 }
